From 28d03238d861a7b6df7abfaf5cfa65ad8fea4ffc Mon Sep 17 00:00:00 2001
From: Romain Courteaud <romain@nexedi.com>
Date: Fri, 4 May 2007 10:15:19 +0000
Subject: [PATCH] Script Career_shiftDefault was renamed

git-svn-id: https://svn.erp5.org/repos/public/erp5/trunk@14352 20353a03-c40f-0410-a6d1-a30d3c3de9de
---
 product/ERP5/tests/testERP5HR.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/product/ERP5/tests/testERP5HR.py b/product/ERP5/tests/testERP5HR.py
index 772c3088b5..e274730f73 100644
--- a/product/ERP5/tests/testERP5HR.py
+++ b/product/ERP5/tests/testERP5HR.py
@@ -646,13 +646,13 @@ class TestHR(ERP5TypeTestCase):
                             title = 'Another Organistion')
     new_career_title = 'new career title'
     # Create a new career step.
-    person.Career_shiftDefault()
+    person.Person_shiftDefaultCareer()
     self.assertEquals( 2,
           len(person.contentValues(filter={'portal_type':'Career'})))
     person.setCareerSubordination(other_organisation.getRelativeUrl())
     person.setCareerTitle(new_career_title)
     
     # Get the new and the old career, as Career_shiftDefault changes
     # objects id, this may be the only safe way ...
     old_career_step = None
     new_career_step = None
@@ -646,13 +646,13 @@ class TestHR(ERP5TypeTestCase):
     person.setCareerTitle(new_career_title)
     
-    # Get the new and the old career, as Career_shiftDefault changes
+    # Get the new and the old career, as Person_shiftDefaultCareer changes
     # objects id, this may be the only safe way ...
     old_career_step = None
-- 
2.30.9